package gui;

import java.awt.AWTEvent;
import java.awt.GridLayout;
import java.awt.Toolkit;
import java.awt.event.AWTEventListener;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;

import javax.swing.JDialog;
import javax.swing.JOptionPane;
import javax.swing.JPanel;

import spiel.Spielfeld;
import spiel.Timer;

public class Field extends JPanel {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	private Spielfeld spielfeld;

	boolean running = false;
	Timer timer;
	Thread timerThread;
	boolean dialog = false;

	int highestScore = 0;
	int lastScore = 0;

	public Field(Spielfeld spielfeld) {
		this.spielfeld = spielfeld;
		this.setLayout(new GridLayout(10, 10));
		fillField(spielfeld.getSpielfeld());
		AWTEventListener ael = new AWTEventListener() {
			public void eventDispatched(AWTEvent event) {
				if (event.getID() == KeyEvent.KEY_PRESSED) {
					move_hero(((KeyEvent) event).getKeyCode());
				}
			}
		};
		Toolkit.getDefaultToolkit().addAWTEventListener(ael,
				AWTEvent.KEY_EVENT_MASK);
		showDialog();
	}

	protected void move_hero(int keyCode) {
		if (running) {
			if (!timerThread.isAlive()) {
				running = false;
				if (highestScore < spielfeld.getScore()){
					lastScore = spielfeld.getScore();
					highestScore = spielfeld.getScore();
				}
				this.spielfeld = new Spielfeld();
				return;
			}
		}
		if (!running) {
			if (timer != null){
				timer.setInterrupt(true);
				
			}
			showDialog();
			return;
		}
		switch (keyCode) {
		case KeyEvent.VK_LEFT:
			spielfeld.geheNachLinks();
			break;
		case KeyEvent.VK_RIGHT:
			spielfeld.geheNachRechts();
			break;
		case KeyEvent.VK_UP:
			spielfeld.geheNachOben();
			break;
		case KeyEvent.VK_DOWN:
			spielfeld.geheNachUnten();
			break;
		}

		fillField(spielfeld.getSpielfeld());

	}

	private void fillField(int[][] spielfeld_matrix) {
		this.removeAll();
		boolean foundHero = false;
		for (int y = 0; y < spielfeld_matrix.length; y++) {
			for (int x = 0; x < spielfeld_matrix[y].length; x++) {

				switch (spielfeld_matrix[y][x]) {
				case 0:
					this.add(new Position(spielfeld.getPfad_zu_SpielfeldBild()));
					break;
				case 1:
					this.add(new Position(spielfeld.getPfad_zu_GegnerBild()));
					break;
				case 2:
					this.add(new Position(spielfeld.getPfad_zu_SchatzBild()));
					break;
				case 3: {
					this.add(new Position(spielfeld.getPfad_zu_HeldBild()));
					;
					foundHero = true;
				}
					break;
				}

			}

		}
		if (!foundHero) {
			running = false;
			showDialog();
		}
		repaint();
		revalidate();
	}

	private void showDialog() {
		if (!dialog) {
			dialog = true;
			Object[] options = { "Start" };
			int n = JOptionPane.showOptionDialog(this, "Erreichte Punkte:"+ lastScore +" Highscore:"
					+ highestScore, "Spielen", JOptionPane.YES_OPTION,
					JOptionPane.INFORMATION_MESSAGE, null, options, options[0]);

			if (n == 0) {
				lastScore = 0;
				running = true;
				this.spielfeld = new Spielfeld();
				fillField(spielfeld.getSpielfeld());
				timer = new Timer();
				timerThread = new Thread(timer);
				timerThread.start();
			}
			dialog = false;
		}
	}
}
